
;**************************************************************************
;*                             hodiny                                     *
;**************************************************************************
;*          pumpa                                                         *
;**************************************************************************
;*          v 1.03 - 07.09.2011 / 05.03.2013                              *
;**************************************************************************
;*          Hardw.: PIC16F628A used                                       *
;*          OSC.......: int osc. used                                     *
;*          POWER.....:  5V                                               *
;**************************************************************************

W                            EQU     H'0000'
F                            EQU     H'0001'

;----- Register Files------------------------------------------------------

INDF                         EQU     H'0000'
TMR0                         EQU     H'0001'
PCL                          EQU     H'0002'
STATUS                       EQU     H'0003'
FSR                          EQU     H'0004'
PORTA                        EQU     H'0005'
PORTB                        EQU     H'0006'

INTCON                       EQU     H'000B'
OPTION_REG                   EQU     H'0081'
TRISA                        EQU     H'0085'
TRISB                        EQU     H'0086'
CMCON                        EQU     H'001F'

PCON                         EQU     H'008E'
PIR1                         EQU     H'000C'	;bank0
PIE1                         EQU     H'008C'	;bank1
T2CON                        EQU     H'0012'	;bank0

TMR2                         EQU     H'0011'	;bank0
PR2			     EQU     H'0092'	;bank1

;----- STATUS Bits --------------------------------------------------------
IRP                          EQU     H'0007'
RP1                          EQU     H'0006'
RP0                          EQU     H'0005'
NOT_TO                       EQU     H'0004'
NOT_PD                       EQU     H'0003'
Z                            EQU     H'0002'
DC                           EQU     H'0001'
C                            EQU     H'0000'

;==========================================================================
;
;       RAM Definition
;
;==========================================================================

    __MAXRAM H'01FF'
    __BADRAM H'07'-H'09', H'0D', H'13'-H'14', H'1B'-H'1E'
    __BADRAM H'87'-H'89', H'8D', H'8F'-H'91', H'93'-H'97', H'9E'
    __BADRAM H'105', H'107'-H'109', H'10C'-H'11F', H'150'-H'16F'
    __BADRAM H'185', H'187'-H'189', H'18C'-H'1EF'

;==========================================================================
;
;       Configuration Bits
;
;==========================================================================

_BODEN_ON                    EQU     H'3FFF'
_BODEN_OFF                   EQU     H'3FBF'
_CP_ALL                      EQU     H'03FF'
_CP_75                       EQU     H'17FF'
_CP_50                       EQU     H'2BFF'
_CP_OFF                      EQU     H'3FFF'
_DATA_CP_ON                  EQU     H'3EFF'
_DATA_CP_OFF                 EQU     H'3FFF'
_PWRTE_OFF                   EQU     H'3FFF'
_PWRTE_ON                    EQU     H'3FF7'
_WDT_ON                      EQU     H'3FFF'
_WDT_OFF                     EQU     H'3FFB'
_LVP_ON                      EQU     H'3FFF'
_LVP_OFF                     EQU     H'3F7F'
_MCLRE_ON                    EQU     H'3FFF'
_MCLRE_OFF                   EQU     H'3FDF'
_ER_OSC_CLKOUT               EQU     H'3FFF'
_ER_OSC_NOCLKOUT             EQU     H'3FFE'
_INTRC_OSC_CLKOUT            EQU     H'3FFD'
_INTRC_OSC_NOCLKOUT          EQU     H'3FFC'
_EXTCLK_OSC                  EQU     H'3FEF'
_LP_OSC                      EQU     H'3FEC'
_XT_OSC                      EQU     H'3FED'
_HS_OSC                      EQU     H'3FEE'


	__CONFIG        _BODEN_OFF & _CP_OFF & _DATA_CP_OFF & _PWRTE_ON & _WDT_OFF & _LVP_OFF & _MCLRE_OFF & _INTRC_OSC_NOCLKOUT


;==========================================================================
;       Variable Definition
;==========================================================================
;INPUTS
SW1		EQU     H'00'		;SW1 is triggering RA0
SW2		EQU     H'01'		;SW2 is triggering RA1
SW3		EQU     H'02'		;SW3 is triggering RA2
SW4		EQU     H'03'		;SW4 is triggering RA3
TIMER1		EQU	H'20'		;Used in delay routine
TIMER2		EQU	H'21'		; "	"	"	

;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.

;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		MOVLW	B'00000111'	;Disable Comparator module's
		MOVWF	CMCON
		;
		BSF	STATUS,RP0	;Switch to register bank 1
					;Disable pull-ups
					;INT on rising edge
					;TMR0 to CLKOUT
					;TMR0 Incr low2high trans.
					;Prescaler assign to Timer0
					;Prescaler rate is 1:256
		MOVLW	B'11010111'	;Set PIC options (See datasheet).
		MOVWF	OPTION_REG	;Write the OPTION register.

		clrf	INTCON		;disable interrupts

		MOVLW	B'00000011'	;RBx = 1 -> input; RBx = 0 -> output
		MOVWF	TRISB
		MOVLW	B'11110000'	;RAx = 1 -> input; RAx = 0 -> output
		MOVWF	TRISA

		bsf	PCON,D'003'	;set 4MHz oscillatory frequency

		BCF	STATUS,RP0	;Switch Back to reg. Bank 0
;----------------------------------------------------------------------------
main001		nop
		clrf	PORTB
		call	d3

		movlw	B'00000100'
		movwf	PORTB

		btfss	PORTB,D'000'
		goto	on001
		btfss	PORTB,D'001'
		goto	on001
		call	d3
		goto	main001
;----------------------------------------------------------------------------
on001
		call	d3
		call	d3
		call	d3
		call	d3

		movlw	B'00001000'
		movwf	PORTB
		bsf	PORTB,D'006'
		call	d3
		call	d3
		call	d3
		call	d3
		call	d3
		call	d3
		call	d3
		call	d3
		call	d3
		call	d3

		goto	main001



;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;
;		*********************************************
;		*               delay routine               *
;		*********************************************

; ~ 400ms

d3		call	delay_routine
		call	delay_routine
		return
;------------------------------------------------------------------------------

; ~ 200ms
delay_routine	MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP1       MOVLW   D'255'
		MOVWF   TIMER1
DEL_LOOP2       DECFSZ  TIMER1,F
                GOTO    DEL_LOOP2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP1
		return
;------------------------------------------------------------------------------

		END